<template>
  <div class="app-container">
    <!-- 搜索工作栏 -->
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch"
             label-width="68px">
      <el-form-item label="问题模板id" prop="templateId">
        <el-input v-model="queryParams.templateId" placeholder="请输入问题模板id" clearable
                  @keyup.enter.native="handleQuery"/>
      </el-form-item>
      <el-form-item label="key" prop="settingKey">
        <el-input v-model="queryParams.settingKey" placeholder="请输入key" clearable
                  @keyup.enter.native="handleQuery"/>
      </el-form-item>
      <el-form-item label="参数名称" prop="settingName">
        <el-input v-model="queryParams.settingName" placeholder="请输入参数名称" clearable
                  @keyup.enter.native="handleQuery"/>
      </el-form-item>
      <el-form-item label="参数默认值" prop="settingValue">
        <el-input v-model="queryParams.settingValue" placeholder="请输入参数默认值" clearable
                  @keyup.enter.native="handleQuery"/>
      </el-form-item>
      <el-form-item label="排序" prop="sort">
        <el-input v-model="queryParams.sort" placeholder="请输入排序" clearable
                  @keyup.enter.native="handleQuery"/>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <!-- 操作工具栏 -->
    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" plain icon="el-icon-plus" size="mini" @click="openForm(undefined)"
                   v-hasPermi="['ai:question-param-setting:create']">新增
        </el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="list" :stripe="true" :show-overflow-tooltip="true">
      <el-table-column label="id" align="center" prop="id"/>
      <el-table-column label="问题模板id" align="center" prop="templateId"/>
      <el-table-column label="key" align="center" prop="settingKey"/>
      <el-table-column label="参数名称" align="center" prop="settingName"/>
      <el-table-column label="参数默认值" align="center" prop="settingValue"/>
      <el-table-column label="排序" align="center" prop="sort"/>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template v-slot="scope">
          <el-button size="mini" type="text" icon="el-icon-edit" @click="openForm(scope.row.id)"
                     v-hasPermi="['ai:question-param-setting:update']">修改
          </el-button>
          <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)"
                     v-hasPermi="['ai:question-param-setting:delete']">删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>
    <!-- 分页组件 -->
    <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNo"
                :limit.sync="queryParams.pageSize"
                @pagination="getList"/>
    <!-- 对话框(添加 / 修改) -->
    <QuestionParamSettingForm ref="formRef" @success="getList"/>
  </div>
</template>

<script>
import * as QuestionParamSettingApi from '@/api/ai/questionparamsetting';
import QuestionParamSettingForm from './QuestionParamSettingForm.vue';

export default {
  name: "QuestionParamSetting",
  components: {
    QuestionParamSettingForm,
  },
  data() {
    return {
      // 遮罩层
      loading: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 大模型问题设置参数列表
      list: [],
      // 是否展开，默认全部展开
      isExpandAll: true,
      // 重新渲染表格状态
      refreshTable: true,
      // 选中行
      currentRow: {},
      // 查询参数
      queryParams: {
        pageNo: 1,
        pageSize: 10,
        templateId: null,
        settingKey: null,
        settingName: null,
        settingValue: null,
        sort: null,
      },
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询列表 */
    async getList() {
      try {
        this.loading = true;
        const res = await QuestionParamSettingApi.getQuestionParamSettingPage(this.queryParams);
        this.list = res.data.list;
        this.total = res.data.total;
      } finally {
        this.loading = false;
      }
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNo = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    /** 添加/修改操作 */
    openForm(id) {
      this.$refs["formRef"].open(id);
    },
    /** 删除按钮操作 */
    async handleDelete(row) {
      const id = row.id;
      await this.$modal.confirm('是否确认删除大模型问题设置参数编号为"' + id + '"的数据项?')
      try {
        await QuestionParamSettingApi.deleteQuestionParamSetting(id);
        await this.getList();
        this.$modal.msgSuccess("删除成功");
      } catch {
      }
    },
  }
};
</script>
